summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/tracedata.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/tracedata.h')
-rw-r--r--kcachegrind/kcachegrind/tracedata.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kcachegrind/kcachegrind/tracedata.h b/kcachegrind/kcachegrind/tracedata.h
index 8fab2b68..cb97e623 100644
--- a/kcachegrind/kcachegrind/tracedata.h
+++ b/kcachegrind/kcachegrind/tracedata.h
@@ -307,7 +307,7 @@ public:
* other cost items. If only one item depends on the cost of this item,
* it can by set with setDependant() without a need for overwriting.
*/
- virtual void invalidate();
+ virtual void tqinvalidate();
/**
* Sets a dependant to be invalidated when this cost is invalidated.
@@ -388,7 +388,7 @@ public:
void maxCost(int index, SubCost value);
TraceCost diff(TraceCost* item);
- virtual void invalidate();
+ virtual void tqinvalidate();
/** Returns a sub cost. This automatically triggers
* a call to update() if needed.
@@ -1549,7 +1549,7 @@ class TraceAssoziation
bool setFunction(TraceFunction*);
TraceFunction* function() { return _function; }
- void invalidate() { _valid = false; }
+ void tqinvalidate() { _valid = false; }
bool isValid() { return _valid; }
/**
@@ -1562,7 +1562,7 @@ class TraceAssoziation
* Invalidate all assoziations in TraceFunctions of data with
* rtti runtime info. rtti = 0: Invalidate ALL assoziations.
*/
- static void invalidate(TraceData* data, int rtti);
+ static void tqinvalidate(TraceData* data, int rtti);
protected:
TraceFunction* _function;
@@ -1590,7 +1590,7 @@ class TraceFunction: public TraceCostItem
virtual CostType type() const { return Function; }
virtual void update();
// this invalidate all subcosts of function depending on
// active status of parts
void invalidateDynamicCost();
@@ -1841,7 +1841,7 @@ class TraceData: public TraceCost
void load(const TQString&);
/** returns true if something changed. These do NOT
* invalidate the dynamic costs on a activation change,
* i.e. all cost items dependend on active parts.
* This has to be done by the caller when true is returned by
* calling invalidateDynamicCost().
@@ -1590,7 +1590,7 @@ class TraceFunction: public TraceCostItem
virtual CostType type() const { return Function; }
virtual void update();
- // this invalidate all subcosts of function depending on
+ // this tqinvalidate all subcosts of function depending on
// active status of parts
void invalidateDynamicCost();
@@ -1841,7 +1841,7 @@ class TraceData: public TraceCost
void load(const TQString&);
/** returns true if something changed. These do NOT
- * invalidate the dynamic costs on a activation change,
+ * tqinvalidate the dynamic costs on a activation change,
* i.e. all cost items dependend on active parts.
* This has to be done by the caller when true is returned by